@@ -7,17 +7,17 @@
 
 use 5.008003;
 
-use Mouse 0.93 ();
+use Mouse 0.97 ();
 use MouseX::App::Cmd 0.08 ();
 use Hash::Merge 0.12 ();
-use IO::All 0.43 ();
-use Template::Toolkit::Simple 0.13 ();
-use YAML::XS 0.35 ();
+use IO::All 0.44 ();
+use Template::Toolkit::Simple 0.14 ();
+use YAML::XS 0.37 ();
 
 #------------------------------------------------------------------------------#
 package Package;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 #------------------------------------------------------------------------------#
 package Package::Command;
@@ -80,10 +80,9 @@ sub execute {
         $cwd =~ s!.*/!!;
         $cwd;
     };
+    $self->_pkg_name($pkg_name);
 
     my $stash = $self->conf->stash;
-    $stash->{pkg}{name} = $pkg_name;
-    $stash->{author}{name} = $Package::Conf::author_name_hack;
 
     if ($to->exists) {
         die <<"..." if not $to->empty;
@@ -227,10 +226,15 @@ has _conf => (
         Package::Conf->new(
             src_dir => $self->from,
             cli_args => $self->_args,
+            pkg_name => $self->_pkg_name,
         );
     },
 );
 
+has _pkg_name => (
+    is => 'rw',
+);
+
 has _args => (
     is => 'rw',
     default => sub {[]},
@@ -257,9 +261,9 @@ From the command line:
     > pkg help
 
     > pkg new \
-            --from=pkg/perl/module-install \
+            --from=pkg/perl/dzil \
             --module=Foo::Bar \
-            --module=Foo::Bar::Baz \
+            --desc='Foo to the Bar' \
             foo-bar-pm
 
 =head1 DESCRIPTION
@@ -278,21 +282,31 @@ other people's templates or create your own.
 Here's the quick and simple way to get started, assuming you are familiar with
 L<cpanm> and C<git>. From the command line:
 
-    > # Go to the directory where you keep your git repos:
-    > cd $HOME/src/
-    > # Get the base pkg directory:
-    > git clone https://github.com/ingydotnet/pkg
-    > # Get a basic pkg template. In the case, for a Perl module:
-    > git clone https://github.com/ingydotnet/perl-basic-pkg pkg/perl/basic
-    > # Edit the conf files appropriately
-    > edit pkg/pkg.conf pkg/perl/pkg.conf pkg/perl/basic/pkg.conf
-    > # Now create a new perl module in the foo-bar-pm directory
-    > pkg new --from=pkg/perl/basic --module=Foo::Bar --module=Foo::Gorch foo-bar-pm
-    > # Make another new module!
-    > pkg new --from=pkg/perl/basic --module=Bar::Bar bar-bar-pm
+    # Go to the directory where you keep your repos:
+    cd $HOME/src/
+    # Get the base pkg directory:
+    git clone https://github.com/ingydotnet/pkg-pkg.git pkg
+    # pkg/README will contain a list of known pkg template repos
+    # Get a basic pkg template. In the case, for a Perl module:
+    git clone https://github.com/rafl/perl-pkg.git pkg/perl
+    # Maybe get a more specific Perl module template:
+    git clone https://github.com/rafl/perl-dzil-pkg.git pkg/perl/dzil
+    # Edit the conf files appropriately
+    edit pkg/pkg.conf pkg/perl/pkg.conf pkg/perl/dzil/pkg.conf
+    # Now create a new perl module in the foo-bar-pm directory
+    pkg new --from=pkg/perl --module=Foo::Bar --desc='Foo Bar' foo-bar-pm
+    # Make another new module!
+    pkg new --from=pkg/perl/dzil --module=Bar::Bar --desc='Bar Bar' bar-bar-pm
 
 That was easy.
 
-=head1 MORE DOCUMENTATION
+=head1 TEMPLATES
 
-Coming soon. :)
+The main template repository is: https://github.com/ingydotnet/pkg-pkg.git
+
+The README in this repo contains repos for many other repos. You can easily
+create your own too. Just make sure there is a C<pkg.conf> file in each
+template dir (even if it is empty). Template directories inherit from their
+parent directory.
+
+More doc soon.
